Rdocumentation
powered by
Learn R Programming
pweight (version 0.0.1)
find_crossing: find the crossing point of the two competing maxima
Description
find the crossing point of the two competing maxima
Usage
find_crossing(eta, gamma)
Arguments
eta
mean
gamma
marginal variance: gamma^2 = 1 + sigma^2, so gamma must be greater than 1