Computes the Spjotvoll p-value weights for multiple testing.
Given estimated means mu of test statistics T,
the weighting scheme optimizes the expected number of discoveries
using T as test statistics in multiple testing
at some specific level q.
Usage
spjotvoll_weights(mu, q)
Arguments
mu
a negative vector, the estimated means of test statistics
q
level at which tests will be performed
Value
The optimal Spjotvoll weights.
Details
Specifically, it is assumed that T are Gaussian with mean
mu. One-sided tests of mu>=0 against mu<0< code="">
are conducted using the test statistics T. To optimize power,
different levels are allocated to different tests.
For more details, see the paper "Optimal Multiple Testing Under a
Gaussian Prior on the Effect Sizes", by Dobriban, Fortney, Kim and Owen,
http://arxiv.org/abs/1504.02935
0<>